@@ -9,16 +9,16 @@
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * 
+ *
  * $Id$
  *
  */
@@ -96,12 +96,11 @@ PyInterpreterState* _pylzma_interpreterState;
     0,
 #endif
 
-#if defined(PY_SSIZE_T_CLEAN) && (PY_VERSION_HEX >= 0x02040000)
-#define PARSE_LENGTH_TYPE   Py_ssize_t
-#define PARSE_LENGTH_FORMAT "%zd"
+// Handle tp_print -> tp_vectorcall_offset change in Python 3.8+
+#if PY_VERSION_HEX >= 0x03080000
+#define PYLZMA_TP_PRINT 0
 #else
-#define PARSE_LENGTH_TYPE   int
-#define PARSE_LENGTH_FORMAT "%d"
+#define PYLZMA_TP_PRINT NULL
 #endif
 
 extern ISzAlloc allocator;
