@@ -43,7 +43,7 @@ void CreateMemoryInStream(CMemoryInStream *stream, Byte *data, size_t size);
 typedef CMemoryInStream CMemoryInOutStream;
 
 void CreateMemoryInOutStream(CMemoryInOutStream *stream);
-Bool MemoryInOutStreamAppend(CMemoryInOutStream *stream, Byte *data, size_t size);
+BoolInt MemoryInOutStreamAppend(CMemoryInOutStream *stream, Byte *data, size_t size);
 
 typedef struct
 {
@@ -64,4 +64,14 @@ typedef struct
 void CreateMemoryOutStream(CMemoryOutStream *stream);
 void MemoryOutStreamDiscard(CMemoryOutStream *stream, size_t size);
 
+typedef struct
+{
+    ILookInStream s;
+    Byte *data;
+    size_t size;
+    size_t avail;
+} CMemoryLookInStream;
+
+void CreateMemoryLookInStream(CMemoryLookInStream *stream, Byte *data, size_t size);
+
 #endif
